@@ -11,19 +11,19 @@
 
 struct integrity_table;
 
-extern int
+int
 read_integrity_table(WIMStruct *wim, u64 num_checked_bytes,
 		     struct integrity_table **table_ret);
 
 #define free_integrity_table(table) FREE(table)
 
-extern int
+int
 write_integrity_table(WIMStruct *wim,
 		      off_t new_blob_table_end,
 		      off_t old_blob_table_end,
 		      struct integrity_table *old_table);
 
-extern int
+int
 check_wim_integrity(WIMStruct *wim);
 
 #endif /* _WIMLIB_INTEGRITY_H */
